==> driza-0.6.1.tar.gz: driza-0.6.1/Driza/operaciones/tfrecuencias.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#descriptivo.py Operación descriptivo

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez
#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


from rpy import *

nombre=u"Tabla de frecuencias"
tipo="Tabla"
#Mensaje de error si es mayor de 30, y continuar si el usuario lo dice

def funcion(dato,variable,caso,opciones):  # Cambiar cosa por caso
	diccionario={}
	lista=[float(x) for x in dato.getCol(variable,caso=caso)]
	tabla=r.table(lista)
	lista.sort()
	from sets import Set
	titulo=list(Set(lista))
	diccionario["titulo"]=titulo
	diccionario["Valores"]=list(tabla)
	return diccionario

def initresultado(resultado,opciones,datos,variable):
	"""Inicializa al objeto resultado, añadiendole lo que crea conveniente"""
	resultado.addTablaSimple("resultado")
	resultado["resultado"].titulo="Tabla de frecuencias"
	lista=[]
	if opciones["caso"]:
		lista.append("Caso")
	lista2=datos.getCasos(variable)
	lista+=map(str,lista2)
	resultado["resultado"].settitulo(lista)


def interfazresultado(resultado,listaopciones):
	"""Este método dice como introducir los datos en la tabla"""
	lista=[]
	variable=listaopciones[0]
	caso=listaopciones[1]
	if caso:
		lista.append(caso)
	diccionario=listaopciones[2]
	lista+=diccionario["Valores"]
	resultado["resultado"].set(variable,lista)

diccionarioopciones={
		"nombre":"Opciones",
		"tipo":"SeleccionMultiple",
		"opciones":["Media","Varianza",u"Desviación","Mediana","Moda","Rango",u"Máximo",u"Mínimo","Curtosis",u"Coeficiente de Asimetría"]}
percentil={"nombre":"Percentil","tipo":"EntradaTexto"}

widget={"tipo":"CalculoSimple","opciones":[]}

==> driza-0.6.3.tar.gz: driza-0.6.3/Driza/operaciones/tfrecuencias.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

#descriptivo.py Operación descriptivo

#Copyright (C) 2006  Inmaculada Luengo Merino, Néstor Arocha Rodríguez
#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


from rpy import *

nombre=u"Tabla de frecuencias"
tipo="Tabla"
diccionarioopciones={
		"nombre":"Opciones",
		"tipo":"SeleccionMultiple",
		"opciones":["Media","Varianza",u"Desviación","Mediana","Moda","Rango",u"Máximo",u"Mínimo","Curtosis",u"Coeficiente de Asimetría"]}
percentil={"nombre":"Percentil","tipo":"EntradaTexto"}

widget={"tipo":"CalculoSimple","opciones":[]}
#Mensaje de error si es mayor de 30, y continuar si el usuario lo dice

def funcion(dato,variable,caso,opciones):  # Cambiar cosa por caso
	diccionario={}
	lista=[float(x) for x in dato.getCol(variable,caso=caso)]
	tabla=r.table(lista)
	lista.sort()
	from sets import Set
	titulo=list(Set(lista))
	diccionario["titulo"]=titulo
	diccionario["Valores"]=list(tabla)
	return diccionario

def initresultado(resultado,opciones,datos,variable):
	"""Inicializa al objeto resultado, añadiendole lo que crea conveniente"""
	resultado.addTablaSimple("resultado")
	resultado["resultado"].titulo="Tabla de frecuencias"
	lista=[]
	if opciones["caso"]:
		lista.append("Caso")
	lista2=datos.getCasos(variable)
	lista+=map(str,lista2)
	resultado["resultado"].settitulo(lista)


def interfazresultado(resultado,listaopciones,floatrender=None):
	"""Este método dice como introducir los datos en la tabla"""
	lista=[]
	variable=listaopciones[0]
	caso=listaopciones[1]
	if caso:
		lista.append(caso)
	diccionario=listaopciones[2]
	lista+=diccionario["Valores"]
	resultado["resultado"].set(variable,lista)

def comprobarentrada(opciones):  
    pass
